@@ -23,7 +23,7 @@ def main():
     engine = sqlalchemy.create_engine(engine_path, isolation_level='SERIALIZABLE')
 
     data_dict = dict()
-    df = pd.DataFrom(data_dict)
+    df = pd.DataFrame(data_dict)
     df['value'] = cell_value
     df.to_sql(table_name, engine)
     return
